@@ -1,7 +1,4 @@
-
-#=============================
 package SNMP::Effective::Host;
-#=============================
 
 use warnings;
 use strict;
@@ -9,6 +6,8 @@ use overload '""'  => sub { shift()->{'_address'} };
 use overload '${}' => sub { shift()->{'_session'} };
 use overload '@{}' => sub { shift()->{'_varlist'} };
 
+our $VERSION = '1.05';
+
 
 BEGIN { ## no critic # for strict
     no strict 'refs';
@@ -29,15 +28,10 @@ BEGIN { ## no critic # for strict
     }
 }
 
-sub data { #==================================================================
-
-    ### init
+sub data {
     my $self = shift;
 
-    ### save data
     if(@_) {
-        
-        ### init save
         my $r       = shift;
         my $ref_oid = shift || '';
         my $iid     = $r->[1]
@@ -46,54 +40,42 @@ sub data { #==================================================================
 
         $ref_oid    =~ s/^\.//mx;
 
-        ### save
         $self->{'_data'}{$ref_oid}{$iid} = $r->[2];
         $self->{'_type'}{$ref_oid}{$iid} = $r->[3];
     }
 
-    ### the end
     return $self->{'_data'};
 }
 
-sub clear_data { #============================================================
-
-    ### init
+sub clear_data {
     my $self = shift;
 
     $self->{'_data'} = {};
     $self->{'_type'} = {};
 
-    ### the end
     return;
 }
 
-sub arg { #===================================================================
-
-    ### init
+sub arg {
     my $self = shift;
     my $arg  = shift;
 
-    ### set value
     if(ref $arg eq 'HASH') {
         $self->{'_arg'}{$_} = $arg->{$_} for(keys %$arg);
     }
 
-    ### the end
-    return wantarray ? (%{$self->{'_arg'}}, DestHost => "$self") : ();
+    return %{$self->{'_arg'}}, DestHost => "$self" if(wantarray);
+    return   $self->{'_arg'};
 }
 
-sub new { #===================================================================
-    
-    ### init
+sub new {
     my $class = shift;
     my $host  = shift or return;
     my $log   = shift;
     my($session, @varlist);
 
-    ### tie
     tie @varlist, "SNMP::Effective::VarList";
 
-    ### the end
     return bless {
         _address  => $host,
         _log      => $log,
@@ -106,8 +88,7 @@ sub new { #===================================================================
     }, $class;
 }
 
-#=============================================================================
-1983;
+1;
 __END__
 
 =head1 NAME
@@ -116,7 +97,7 @@ SNMP::Effective::Host - Helper module for SNMP::Effective
 
 =head1 VERSION
 
-This document refers to version 0.04 of SNMP::Effective::Host.
+This document refers to version 1.05 of SNMP::Effective::Host.
 
 =head1 DESCRIPTION
 
